ngff_zarr.rich_dask_progress - ngff-zarr
Description: Module Contents: Classes:,, NgffProgress,,, NgffProgressCallback,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.rich_dask_progress`

## Module Contents

### Classes

`NgffProgress` |
`NgffProgressCallback` |

### API

class ngff_zarr.rich_dask_progress.NgffProgress(rich_progress)

  Initialization

  add_multiscales_task(description: str, scales: int)
  update_multiscales_task_completed(completed: int)
  add_cache_task(description: str, total: int)
  update_cache_task_completed(completed: int)

class ngff_zarr.rich_dask_progress.NgffProgressCallback(rich_progress)

  Bases: `dask.callbacks.Callback`, `ngff_zarr.rich_dask_progress.NgffProgress`

  Initialization

  add_callback_task(description: str)
  _start(dsk)
  _start_state(dsk, state)
  _pretask(key, dsk, state)
  _posttask(key, result, dsk, state, worker_id)
  _finish(dsk, state, errored)